@@ -7,36 +7,45 @@
 #include "regression.h"
 #include "rangefunc.h"
 #include "workbook.h"
-#include "application.h"
 #include <gsf/gsf-impl-utils.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
+/*
+ * This is based on the algorithm from "An Automatic Method for finding
+ * the Greatest or Least Value of a Function" by H. H. Rosenbrock
+ * published in _The Computer Journal_ (1960) 3(3): 175-184.
+ *
+ * It is thus 50+ years old.  You would think that advances in computer
+ * science would have produced improvements that would run circles
+ * around this, but that is not obviously true.
+ *
+ * There are a couple of attrictive features of the Rosenbrock method:
+ * 1. It's monotonic.  Unlike Newton-style methods it cannot suddenly
+ *    warp far away.
+ * 2. We don't need the Hessian.
+ *
+ * Note, that in order to speed convergence we occasionally perform
+ * a tentative Newton iteration step.  (It's tentative because we will
+ * discard it if it doesn't lead to an immediate improvement.)
+ */
+
 #define PRIVATE_KEY "::nlsolve::"
 
 /*
  * Note: the solver code assumes the problem is a minimization problem.
  * When used for a maximization problem, we flip the objective function
- * sign.  This is done in functions get_value and gnm_nlsolve_set_solution.
+ * sign.
  */
 
 
 typedef struct {
-	GnmSolver *parent;
+	/* The solver object in two forms.  */
+	GnmSolver *sol;
+	GnmIterSolver *isol;
 
-	/* Input/output cells.  */
-	GPtrArray *vars;
-	GnmCell *target;
-	GnmCellPos origin;
-	int input_width, input_height;
-	gboolean maximize; /* See note above */
-
-	/* Initial point.  */
-	gnm_float *x0;
-
-	/* Current point.  */
-	gnm_float *xk, yk;
-	int k;
+	/* Number of vars.  */
+	int n;
 
 	/* Rosenbrock state */
 	gnm_float **xi;
@@ -46,54 +55,40 @@ typedef struct {
 
 	/* Parameters: */
 	gboolean debug;
-	int max_iter;
 	gnm_float min_factor;
-
-	guint idle_tag;
 } GnmNlsolve;
 
-static void free_matrix (gnm_float **m, int n);
-
-static void
-gnm_nlsolve_cleanup (GnmNlsolve *nl)
-{
-	if (nl->idle_tag) {
-		g_source_remove (nl->idle_tag);
-		nl->idle_tag = 0;
-	}
-}
-
-static void
-gnm_nlsolve_final (GnmNlsolve *nl)
-{
-	const int n = nl->vars->len;
-
-	gnm_nlsolve_cleanup (nl);
-	if (nl->vars)
-		g_ptr_array_free (nl->vars, TRUE);
-	g_free (nl->xk);
-	g_free (nl->x0);
-	if (nl->xi) {
-		free_matrix (nl->xi, n);
-		nl->xi = NULL;
-	}
-
-	g_free (nl);
-}
-
 static gboolean
-check_program (const GnmSolverParameters *params, GError **err)
+check_program (GnmSolver *sol, GError **err)
 {
+	unsigned ui;
+	const GnmSolverParameters *params = sol->params;
 	GSList *l;
 
-	if (params->options.assume_discrete)
-		goto no_discrete;
-
 	for (l = params->constraints; l; l = l->next) {
 		GnmSolverConstraint *c  = l->data;
-		if (c->type == GNM_SOLVER_INTEGER ||
-		    c->type == GNM_SOLVER_BOOLEAN)
+		switch (c->type) {
+		case GNM_SOLVER_EQ:
+			/*
+			 * This catches also equalities where the sides are not
+			 * input variables.
+			 */
+			goto no_equal;
+		default:
+			break;
+		}
+	}
+
+	for (ui = 0; ui < sol->input_cells->len; ui++) {
+		if (sol->discrete[ui])
 			goto no_discrete;
+
+		/*
+		 * This also catches using two inequality constraints used
+		 * to emulate equality.
+		 */
+		if (sol->min[ui] == sol->max[ui])
+			goto no_equal;
 	}
 
 	return TRUE;
@@ -104,6 +99,13 @@ no_discrete:
 		     0,
 		     _("This solver does not handle discrete variables."));
 	return FALSE;
+
+no_equal:
+	g_set_error (err,
+		     go_error_invalid (),
+		     0,
+		     _("This solver does not handle equality constraints."));
+	return FALSE;
 }
 
 static void
@@ -121,39 +123,21 @@ print_vector (const char *name, const gnm_float *v, int n)
 static void
 set_value (GnmNlsolve *nl, int i, gnm_float x)
 {
-	GnmCell *cell = g_ptr_array_index (nl->vars, i);
-	if (cell->value &&
-	    VALUE_IS_FLOAT (cell->value) &&
-	    value_get_as_float (cell->value) == x)
-		return;
-
-	gnm_cell_set_value (cell, value_new_float (x));
-	cell_queue_recalc (cell);
+	gnm_solver_set_var (nl->sol, i, x);
 }
 
 static void
 set_vector (GnmNlsolve *nl, const gnm_float *xs)
 {
-	const int n = nl->vars->len;
-	int i;
-
-	for (i = 0; i < n; i++)
-		set_value (nl, i, xs[i]);
+	gnm_solver_set_vars (nl->sol, xs);
 }
 
+/* Get the target value as-if we were minimizing.  */
 static gnm_float
 get_value (GnmNlsolve *nl)
 {
-	GnmValue const *v;
-
-	gnm_cell_eval (nl->target);
-	v = nl->target->value;
-
-	if (VALUE_IS_NUMBER (v) || VALUE_IS_EMPTY (v)) {
-		gnm_float y = value_get_as_float (v);
-		return nl->maximize ? 0 - y : y;
-	} else
-		return gnm_nan;
+	/* nl->sol has been taught to flip sign if needed.  */
+	return gnm_solver_get_target_value (nl->sol);
 }
 
 static void
@@ -166,60 +150,10 @@ free_matrix (gnm_float **m, int n)
 }
 
 static void
-gnm_nlsolve_set_solution (GnmNlsolve *nl)
+set_solution (GnmNlsolve *nl)
 {
-	GnmSolver *sol = nl->parent;
-	GnmSolverResult *result = g_object_new (GNM_SOLVER_RESULT_TYPE, NULL);
-	const int n = nl->vars->len;
-	int i;
-
-	result->quality = GNM_SOLVER_RESULT_FEASIBLE;
-	result->value = nl->maximize ? 0 - nl->yk : nl->yk;
-	result->solution = value_new_array_empty (nl->input_width,
-						  nl->input_height);
-	for (i = 0; i < n; i++) {
-		GnmCell *cell = g_ptr_array_index (nl->vars, i);
-		value_array_set (result->solution,
-				 cell->pos.col - nl->origin.col,
-				 cell->pos.row - nl->origin.row,
-				 value_new_float (nl->xk[i]));
-	}
-
-	g_object_set (sol, "result", result, NULL);
-	g_object_unref (result);
-
-	if (!gnm_solver_check_constraints (sol)) {
-		g_printerr ("Infeasible solution set\n");
-	}
-}
-
-static gboolean
-gnm_nlsolve_get_initial_solution (GnmNlsolve *nl, GError **err)
-{
-	GnmSolver *sol = nl->parent;
-	const int n = nl->vars->len;
-	int i;
-
-	if (gnm_solver_check_constraints (sol))
-		goto got_it;
-
-	/* More? */
-
-	g_set_error (err,
-		     go_error_invalid (),
-		     0,
-		     _("The initial values do not satisfy the constraints."));
-	return FALSE;
-
-got_it:
-	for (i = 0; i < n; i++) {
-		GnmCell *cell = g_ptr_array_index (nl->vars, i);
-		nl->xk[i] = nl->x0[i] = value_get_as_float (cell->value);
-	}
-	nl->yk = get_value (nl);
-	gnm_nlsolve_set_solution (nl);
-
-	return TRUE;
+	/* nl->isol has been taught to flip sign if needed.  */
+	gnm_iter_solver_set_solution (nl->isol);
 }
 
 static gboolean
@@ -232,14 +166,13 @@ gnm_nlsolve_prepare (GnmSolver *sol, WorkbookControl *wbc, GError **err,
 
 	gnm_solver_set_status (sol, GNM_SOLVER_STATUS_PREPARING);
 
-	ok = check_program (sol->params, err);
+	ok = check_program (sol, err);
 	if (ok)
-		ok = gnm_nlsolve_get_initial_solution (nl, err);
+		ok = gnm_iter_solver_get_initial_solution (nl->isol, err);
 
 	if (ok) {
 		gnm_solver_set_status (sol, GNM_SOLVER_STATUS_PREPARED);
 	} else {
-		gnm_nlsolve_cleanup (nl);
 		gnm_solver_set_status (sol, GNM_SOLVER_STATUS_ERROR);
 	}
 
@@ -249,41 +182,14 @@ gnm_nlsolve_prepare (GnmSolver *sol, WorkbookControl *wbc, GError **err,
 static gnm_float *
 compute_gradient (GnmNlsolve *nl, const gnm_float *xs)
 {
-	gnm_float *g;
-	gnm_float y0;
-	const int n = nl->vars->len;
-	int i;
-
-	set_vector (nl, xs);
-	y0 = get_value (nl);
-
-	g = g_new (gnm_float, n);
-	for (i = 0; i < n; i++) {
-		gnm_float x0 = xs[i];
-		gnm_float dx;
-		gnm_float y1;
-		gnm_float eps = gnm_pow2 (-25);
-
-		if (x0 == 0)
-			dx = eps;
-		else
-			dx = gnm_abs (x0) * eps;
-
-		set_value (nl, i, x0 + dx);
-		y1 = get_value (nl);
-		g[i] = (y1 - y0) / dx;
-
-		set_value (nl, i, x0);
-	}
-
-	return g;
+	return gnm_solver_compute_gradient (nl->sol, xs);
 }
 
 static gnm_float **
 compute_hessian (GnmNlsolve *nl, const gnm_float *xs, const gnm_float *g0)
 {
 	gnm_float **H, *xs2;
-	const int n = nl->vars->len;
+	const int n = nl->n;
 	int i, j;
 
 	H = g_new (gnm_float *, n);
@@ -325,8 +231,8 @@ compute_hessian (GnmNlsolve *nl, const gnm_float *xs, const gnm_float *g0)
 static gboolean
 newton_improve (GnmNlsolve *nl, gnm_float *xs, gnm_float *y, gnm_float ymax)
 {
-	GnmSolver *sol = nl->parent;
-	const int n = nl->vars->len;
+	GnmSolver *sol = nl->sol;
+	const int n = nl->n;
 	gnm_float *g, **H, *d;
 	gboolean ok;
 
@@ -383,7 +289,7 @@ newton_improve (GnmNlsolve *nl, gnm_float *xs, gnm_float *y, gnm_float ymax)
 static void
 rosenbrock_init (GnmNlsolve *nl)
 {
-	const int n = nl->vars->len;
+	const int n = nl->n;
 	int i, j;
 
 	nl->xi = g_new (gnm_float *, n);
@@ -402,11 +308,12 @@ rosenbrock_init (GnmNlsolve *nl)
 static void
 rosenbrock_tentative_end (GnmNlsolve *nl, gboolean accept)
 {
-	const int n = nl->vars->len;
+	const int n = nl->n;
+	GnmIterSolver *isol = nl->isol;
 
 	if (!accept && nl->tentative_xk) {
-		nl->yk = nl->tentative_yk;
-		memcpy (nl->xk, nl->tentative_xk, n * sizeof (gnm_float));
+		nl->isol->yk = nl->tentative_yk;
+		memcpy (isol->xk, nl->tentative_xk, n * sizeof (gnm_float));
 	}
 
 	nl->tentative = 0;
@@ -419,8 +326,9 @@ rosenbrock_tentative_end (GnmNlsolve *nl, gboolean accept)
 static gboolean
 rosenbrock_iter (GnmNlsolve *nl)
 {
-	GnmSolver *sol = nl->parent;
-	const int n = nl->vars->len;
+	GnmSolver *sol = nl->sol;
+	GnmIterSolver *isol = nl->isol;
+	const int n = nl->n;
 	int i, j;
 	const gnm_float alpha = 3;
 	const gnm_float beta = 0.5;
@@ -428,7 +336,7 @@ rosenbrock_iter (GnmNlsolve *nl)
 	gnm_float *d, **A, *x, *dx, *t;
 	char *state;
 	int dones = 0;
-	gnm_float ykm1 = nl->yk, *xkm1;
+	gnm_float ykm1 = isol->yk, *xkm1;
 	gnm_float eps = gnm_pow2 (-16);
 	int safety = 0;
 
@@ -441,7 +349,7 @@ rosenbrock_iter (GnmNlsolve *nl)
 		}
 	}
 
-	if (nl->k % 20 == 0) {
+	if (isol->iterations % 20 == 0) {
 		for (i = 0; i < n; i++)
 			for (j = 0; j < n; j++)
 				nl->xi[i][j] = (i == j);
@@ -460,12 +368,12 @@ rosenbrock_iter (GnmNlsolve *nl)
 
 	d = g_new (gnm_float, n);
 	for (i = 0; i < n; i++) {
-		d[i] = (nl->xk[i] == 0)
+		d[i] = (isol->xk[i] == 0)
 			? eps
-			: gnm_abs (nl->xk[i]) * eps;
+			: gnm_abs (isol->xk[i]) * eps;
 	}
 
-	xkm1 = g_memdup (nl->xk, n * sizeof (gnm_float));
+	xkm1 = g_memdup (isol->xk, n * sizeof (gnm_float));
 
 	state = g_new0 (char, n);
 
@@ -485,15 +393,15 @@ rosenbrock_iter (GnmNlsolve *nl)
 
 			/* x = xk + (d[i] * xi[i])  */
 			for (j = 0; j < n; j++)
-				x[j] = nl->xk[j] + d[i] * nl->xi[i][j];
+				x[j] = isol->xk[j] + d[i] * nl->xi[i][j];
 
 			set_vector (nl, x);
 			y = get_value (nl);
 
-			if (y <= nl->yk && gnm_solver_check_constraints (sol)) {
-				if (y < nl->yk) {
-					nl->yk = y;
-					memcpy (nl->xk, x, n * sizeof (gnm_float));
+			if (y <= isol->yk && gnm_solver_check_constraints (sol)) {
+				if (y < isol->yk) {
+					isol->yk = y;
+					memcpy (isol->xk, x, n * sizeof (gnm_float));
 					dx[i] += d[i];
 					any_at_all = TRUE;
 				}
@@ -565,41 +473,41 @@ rosenbrock_iter (GnmNlsolve *nl)
 		/* ---------------------------------------- */
 
 		if (!nl->tentative) {
-			set_vector (nl, nl->xk);
-			gnm_nlsolve_set_solution (nl);
+			set_vector (nl, isol->xk);
+			set_solution (nl);
 		}
 
 		if (nl->tentative) {
-			if (nl->yk < nl->tentative_yk) {
+			if (isol->yk < nl->tentative_yk) {
 				if (nl->debug)
 					g_printerr ("Tentative move accepted!\n");
 				rosenbrock_tentative_end (nl, TRUE);
 			}
-		} else if (gnm_abs (nl->yk - ykm1) > gnm_abs (ykm1) * 0.01) {
+		} else if (gnm_abs (isol->yk - ykm1) > gnm_abs (ykm1) * 0.01) {
 			/* A big step.  */
 			nl->smallsteps = 0;
 		} else {
 			nl->smallsteps++;
 		}
 
-		if (!nl->tentative && nl->smallsteps > 50) {
-			gnm_float yk = nl->yk;
+		if (0 && !nl->tentative && nl->smallsteps > 50) {
+			gnm_float yk = isol->yk;
 
 			nl->tentative = 10;
-			nl->tentative_xk = g_memdup (nl->xk, n * sizeof (gnm_float));
+			nl->tentative_xk = g_memdup (isol->xk, n * sizeof (gnm_float));
 			nl->tentative_yk = yk;
 
 			for (i = 0; i < 4; i++) {
 				gnm_float ymax = yk +
 					gnm_abs (yk) * (0.10 / (i + 1));
 				if (i > 0)
-					ymax = MIN (ymax, nl->yk);
-				if (!newton_improve (nl, nl->xk, &nl->yk, ymax))
+					ymax = MIN (ymax, isol->yk);
+				if (!newton_improve (nl, isol->xk, &isol->yk, ymax))
 					break;
 			}
 
 			if (nl->debug)
-				print_vector ("Tentative move to", nl->xk, n);
+				print_vector ("Tentative move to", isol->xk, n);
 		}
 	}
 
@@ -614,141 +522,45 @@ rosenbrock_iter (GnmNlsolve *nl)
 	return any_at_all;
 }
 
-static void
-rosenbrock_shutdown (GnmNlsolve *nl)
-{
-	const int n = nl->vars->len;
-
-	rosenbrock_tentative_end (nl, FALSE);
-
-	free_matrix (nl->xi, n);
-	nl->xi = NULL;
-}
-
 static gboolean
-polish_iter (GnmNlsolve *nl)
+gnm_nlsolve_iterate (GnmSolverIterator *iter, GnmNlsolve *nl)
 {
-	GnmSolver *sol = nl->parent;
-	const int n = nl->vars->len;
-	gnm_float *x;
-	gnm_float step;
-	gboolean any_at_all = FALSE;
+	GnmIterSolver *isol = nl->isol;
+	const int n = nl->n;
 
-	x = g_new (gnm_float, n);
-	for (step = gnm_pow2 (-10); step > GNM_EPSILON; step *= 0.75) {
-		int c, s;
-
-		for (c = 0; c < n; c++) {
-			for (s = 0; s <= 1; s++) {
-				gnm_float y;
-				gnm_float dx = step * gnm_abs (nl->xk[c]);
-
-				if (dx == 0) dx = step;
-				if (s) dx = -dx;
-
-				memcpy (x, nl->xk, n * sizeof (gnm_float));
-				x[c] += dx;
-				set_vector (nl, x);
-				y = get_value (nl);
-
-				if (y < nl->yk && gnm_solver_check_constraints (sol))  {
-					nl->yk = y;
-					memcpy (nl->xk, x, n * sizeof (gnm_float));
-					any_at_all = TRUE;
-					if (nl->debug)
-						g_printerr ("Polish step %.15" GNM_FORMAT_g
-							    " in direction %d\n",
-							    dx, c);
-					break;
-				}
-			}
-		}
-	}
-
-	g_free (x);
-
-	if (any_at_all)
-		gnm_nlsolve_set_solution (nl);
-
-	return any_at_all;
-}
-
-static gint
-gnm_nlsolve_idle (gpointer data)
-{
-	GnmNlsolve *nl = data;
-	GnmSolver *sol = nl->parent;
-	const int n = nl->vars->len;
-	gboolean ok;
-	gboolean call_again = TRUE;
-
-	if (nl->k == 0)
+	if (isol->iterations == 0)
 		rosenbrock_init (nl);
 
 	if (nl->debug) {
-		g_printerr ("Iteration %d at %.15" GNM_FORMAT_g "\n",
-			    nl->k, nl->yk);
-		print_vector ("Current point", nl->xk, n);
+		g_printerr ("Iteration %ld at %.15" GNM_FORMAT_g "\n",
+			    (long)(isol->iterations), isol->yk);
+		print_vector ("Current point", isol->xk, n);
 	}
 
-	nl->k++;
-	ok = rosenbrock_iter (nl);
-
-	if (!ok && !nl->tentative) {
-		ok = polish_iter (nl);
-	}
-
-	if (!ok) {
-		gnm_solver_set_status (sol, GNM_SOLVER_STATUS_DONE);
-		call_again = FALSE;
-	}
-
-	if (call_again && nl->k >= nl->max_iter) {
-		gnm_solver_set_status (sol, GNM_SOLVER_STATUS_DONE);
-		call_again = FALSE;
-	}
-
-	if (!call_again) {
-		set_vector (nl, nl->x0);
-		gnm_app_recalc ();
-
-		rosenbrock_shutdown (nl);
-	}
-
-	if (!call_again)
-		nl->idle_tag = 0;
-
-	return call_again;
+	return rosenbrock_iter (nl);
 }
 
-static gboolean
-gnm_nlsolve_start (GnmSolver *sol, WorkbookControl *wbc, GError **err,
-		   GnmNlsolve *nl)
+static void
+gnm_nlsolve_final (GnmNlsolve *nl)
 {
-	gboolean ok = TRUE;
+	const int n = nl->n;
 
-	g_return_val_if_fail (sol->status == GNM_SOLVER_STATUS_PREPARED, FALSE);
+	/* Accept, i.e., don't try to restore.  */
+	rosenbrock_tentative_end (nl, TRUE);
 
-	nl->idle_tag = g_idle_add (gnm_nlsolve_idle, nl);
-	gnm_solver_set_status (sol, GNM_SOLVER_STATUS_RUNNING);
+	if (nl->xi) {
+		free_matrix (nl->xi, n);
+		nl->xi = NULL;
+	}
 
-	return ok;
+	g_free (nl);
 }
 
-static gboolean
-gnm_nlsolve_stop (GnmSolver *sol, GError *err, GnmNlsolve *nl)
-{
-	g_return_val_if_fail (sol->status == GNM_SOLVER_STATUS_RUNNING, FALSE);
+/* ------------------------------------------------------------------------- */
+/* Plug-in interface.  */
 
-	gnm_nlsolve_cleanup (nl);
-
-	gnm_solver_set_status (sol, GNM_SOLVER_STATUS_CANCELLED);
-
-	return TRUE;
-}
-
-gboolean
-nlsolve_solver_factory_functional (GnmSolverFactory *factory);
+gboolean nlsolve_solver_factory_functional (GnmSolverFactory *factory);
+GnmSolver *nlsolve_solver_factory (GnmSolverFactory *factory, GnmSolverParameters *params);
 
 gboolean
 nlsolve_solver_factory_functional (GnmSolverFactory *factory)
@@ -756,58 +568,41 @@ nlsolve_solver_factory_functional (GnmSolverFactory *factory)
 	return TRUE;
 }
 
-
-GnmSolver *
-nlsolve_solver_factory (GnmSolverFactory *factory, GnmSolverParameters *params);
-
 GnmSolver *
 nlsolve_solver_factory (GnmSolverFactory *factory, GnmSolverParameters *params)
 {
-	GnmSolver *res = g_object_new (GNM_SOLVER_TYPE,
-				       "params", params,
-				       NULL);
+	GnmIterSolver *isol = g_object_new
+		(GNM_ITER_SOLVER_TYPE,
+		 "params", params,
+		 "flip-sign", (params->problem_type == GNM_SOLVER_MAXIMIZE),
+		 NULL);
+	GnmSolver *sol = GNM_SOLVER (isol);
 	GnmNlsolve *nl = g_new0 (GnmNlsolve, 1);
-	GSList *input_cells, *l;
-	int n;
-	GnmValue const *vinput = gnm_solver_param_get_input (params);
-	GnmEvalPos ep;
-	GnmCellRef origin;
+	GnmSolverIteratorCompound *citer;
+	GnmSolverIterator *iter;
 
-	nl->parent = GNM_SOLVER (res);
+	citer = g_object_new (GNM_SOLVER_ITERATOR_COMPOUND_TYPE, NULL);
 
-	nl->maximize = (params->problem_type == GNM_SOLVER_MAXIMIZE);
+	iter = gnm_solver_iterator_new_func (G_CALLBACK (gnm_nlsolve_iterate), nl);
+	gnm_solver_iterator_compound_add (citer, iter, 1);
 
-	eval_pos_init_sheet (&ep, params->sheet);
-	if (vinput) {
-		gnm_cellref_make_abs (&origin, &vinput->v_range.cell.a, &ep);
-		nl->origin.col = origin.col;
-		nl->origin.row = origin.row;
-		nl->input_width = value_area_get_width (vinput, &ep);
-		nl->input_height = value_area_get_height (vinput, &ep);
-	}
+	gnm_solver_iterator_compound_add (citer, gnm_solver_iterator_new_polish (isol), 0);
 
+	gnm_iter_solver_set_iterator (isol, GNM_SOLVER_ITERATOR (citer));
+	g_object_unref (citer);
+
+	nl->sol = sol;
+	nl->isol = isol;
 	nl->debug = gnm_solver_debug ();
-	nl->max_iter = params->options.max_iter;
 	nl->min_factor = 1e-10;
+	nl->n = nl->sol->input_cells->len;
 
-	nl->target = gnm_solver_param_get_target_cell (params);
+	g_signal_connect (isol, "prepare", G_CALLBACK (gnm_nlsolve_prepare), nl);
 
-	nl->vars = g_ptr_array_new ();
-	input_cells = gnm_solver_param_get_input_cells (params);
-	for (l = input_cells; l; l = l->next)
-		g_ptr_array_add (nl->vars, l->data);
-	g_slist_free (input_cells);
-	n = nl->vars->len;
-
-	nl->x0 = g_new (gnm_float, n);
-	nl->xk = g_new (gnm_float, n);
-
-	g_signal_connect (res, "prepare", G_CALLBACK (gnm_nlsolve_prepare), nl);
-	g_signal_connect (res, "start", G_CALLBACK (gnm_nlsolve_start), nl);
-	g_signal_connect (res, "stop", G_CALLBACK (gnm_nlsolve_stop), nl);
-
-	g_object_set_data_full (G_OBJECT (res), PRIVATE_KEY, nl,
+	g_object_set_data_full (G_OBJECT (isol), PRIVATE_KEY, nl,
 				(GDestroyNotify)gnm_nlsolve_final);
 
-	return res;
+	return sol;
 }
+
+/* ------------------------------------------------------------------------- */
