@@ -161,7 +161,7 @@ normality_tool_ok_clicked_cb (G_GNUC_UNUSED GtkWidget *button,
 	w = go_gtk_builder_get_widget (state->base.gui, "normalprobabilityplot");
 	data->graph = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (w));
 
-	if (!cmd_analysis_tool (WORKBOOK_CONTROL (state->base.wbcg),
+	if (!cmd_analysis_tool (GNM_WBC (state->base.wbcg),
 				state->base.sheet,
 				dao, data, analysis_tool_normality_engine,
 				TRUE))
@@ -191,7 +191,7 @@ dialog_normality_tool (WBCGtk *wbcg, Sheet *sheet)
 		return 1;
 
 	/* Only pop up one copy per workbook */
-	if (gnumeric_dialog_raise_if_exists (wbcg, NORMALITY_KEY))
+	if (gnm_dialog_raise_if_exists (wbcg, NORMALITY_KEY))
 		return 0;
 
 	state = g_new0 (NormalityTestsToolState, 1);
