@@ -691,7 +691,7 @@ c_fmt_dialog_set_conditions (CFormatState *state, char const *cmd_label)
 				      (GnmSelectionFunc)c_fmt_dialog_condition_setter_tiled,
 				      state);
 	}
-	cmd_generic_with_size (WORKBOOK_CONTROL (state->wbcg), cmd_label,
+	cmd_generic_with_size (GNM_WBC (state->wbcg), cmd_label,
 			       state->action.size, state->action.undo, state->action.redo);
 
 	state->action.undo = NULL;
@@ -1306,7 +1306,7 @@ dialog_cell_format_cond (WBCGtk *wbcg)
 	state = g_new (CFormatState, 1);
 	state->wbcg	= wbcg;
 	state->gui	= gui;
-	state->sv	= wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg));
+	state->sv	= wb_control_cur_sheet_view (GNM_WBC (wbcg));
 	state->sheet	= sv_sheet (state->sv);
 	state->style	= NULL;
 	state->editor.style = NULL;
@@ -1325,7 +1325,7 @@ dialog_cell_format_cond (WBCGtk *wbcg)
 
 	c_fmt_dialog_load (state);
 
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (state->gui, "helpbutton"),
 		GNUMERIC_HELP_LINK_CELL_FORMAT_COND);
 
@@ -1344,7 +1344,7 @@ dialog_cell_format_cond (WBCGtk *wbcg)
 	g_signal_connect (G_OBJECT (dialog), "destroy",
 			  G_CALLBACK (cb_dialog_destroy), NULL);
 
-	gnumeric_restore_window_geometry (GTK_WINDOW (state->dialog),
+	gnm_restore_window_geometry (GTK_WINDOW (state->dialog),
 					  CELL_FORMAT_KEY);
 
 	go_gtk_nonmodal_dialog (wbcg_toplevel (state->wbcg),
