@@ -102,7 +102,7 @@ static void
 search_get_value (gint row, gint column, gpointer _dd, GValue *value)
 {
 	DialogState *dd = (DialogState *)_dd;
-	GnumericLazyList *ll = GNUMERIC_LAZY_LIST (gtk_tree_view_get_model (dd->matches_table));
+	GnumericLazyList *ll = GNM_LAZY_LIST (gtk_tree_view_get_model (dd->matches_table));
 	GnmSearchFilterResult *item = g_ptr_array_index (dd->matches, row);
 	GnmCell *cell;
 	GnmComment *comment;
@@ -286,7 +286,7 @@ cursor_change (GtkTreeView *tree_view, DialogState *dd)
 		GnmSearchFilterResult *item = g_ptr_array_index (dd->matches, matchno);
 		int col = item->ep.eval.col;
 		int row = item->ep.eval.row;
-		WorkbookControl *wbc = WORKBOOK_CONTROL (dd->wbcg);
+		WorkbookControl *wbc = GNM_WBC (dd->wbcg);
 		WorkbookView *wbv = wb_control_view (wbc);
 		SheetView *sv;
 
@@ -309,7 +309,7 @@ search_clicked (G_GNUC_UNUSED GtkWidget *widget, DialogState *dd)
 {
 	GtkBuilder *gui = dd->gui;
 	WBCGtk *wbcg = dd->wbcg;
-	WorkbookControl *wbc = WORKBOOK_CONTROL (wbcg);
+	WorkbookControl *wbc = GNM_WBC (wbcg);
 	GnmSearchReplace *sr;
 	char *err;
 	int i;
@@ -525,7 +525,7 @@ dialog_search (WBCGtk *wbcg)
 	{
 		char *selection_text =
 			selection_to_string (
-				wb_control_cur_sheet_view (WORKBOOK_CONTROL (wbcg)),
+				wb_control_cur_sheet_view (GNM_WBC (wbcg)),
 				TRUE);
 		gnm_expr_entry_load_from_text  (dd->rangetext, selection_text);
 		g_free (selection_text);
@@ -535,7 +535,7 @@ dialog_search (WBCGtk *wbcg)
 	gtk_widget_set_hexpand (GTK_WIDGET (dd->gentry), TRUE);
 	gtk_grid_attach (grid, GTK_WIDGET (dd->gentry), 1, 0, 1, 1);
 	gtk_widget_grab_focus (GTK_WIDGET (dd->gentry));
-	gnumeric_editable_enters (GTK_WINDOW (dialog), GTK_WIDGET (dd->gentry));
+	gnm_editable_enters (GTK_WINDOW (dialog), GTK_WIDGET (dd->gentry));
 
 	dd->matches_table = make_matches_table (dd);
 
@@ -607,10 +607,10 @@ dialog_search (WBCGtk *wbcg)
 		"state", dd, (GDestroyNotify) free_state);
 	gnm_dialog_setup_destroy_handlers (dialog, wbcg,
 		GNM_DIALOG_DESTROY_SHEET_REMOVED);
-	gnumeric_init_help_button (
+	gnm_init_help_button (
 		go_gtk_builder_get_widget (gui, "help_button"),
 		GNUMERIC_HELP_LINK_SEARCH);
-	gnumeric_restore_window_geometry (GTK_WINDOW (dialog), SEARCH_KEY);
+	gnm_restore_window_geometry (GTK_WINDOW (dialog), SEARCH_KEY);
 
 	go_gtk_nonmodal_dialog (wbcg_toplevel (wbcg), GTK_WINDOW (dialog));
 	gtk_widget_show_all (GTK_WIDGET (dialog));
