@@ -26,6 +26,7 @@
 #include "gnm-so-path.h"
 #include "sheet-object-impl.h"
 #include "sheet.h"
+#include "gutils.h"
 #include "xml-sax.h"
 
 #include <goffice/goffice.h>
@@ -147,7 +148,7 @@ so_path_goc_view_class_init (SheetObjectViewClass *sov_klass)
 typedef SheetObjectViewClass	GnmSOPathViewClass;
 static GSF_CLASS (GnmSOPathView, so_path_goc_view,
 	so_path_goc_view_class_init, NULL,
-	SHEET_OBJECT_VIEW_TYPE)
+	GNM_SO_VIEW_TYPE)
 
 #endif
 
@@ -194,16 +195,16 @@ static void
 gnm_so_path_user_config (SheetObject *so, SheetControl *sc)
 {
 	GnmSOPath *sop = GNM_SO_PATH (so);
-	dialog_so_styled (scg_wbcg (SHEET_CONTROL_GUI (sc)), G_OBJECT (so),
-			  sop->style, sop_default_style (),
+	dialog_so_styled (scg_wbcg (GNM_SCG (sc)), G_OBJECT (sop),
+			  sop_default_style (),
 			  _("Filled Object Properties"),
 			  SO_STYLED_TEXT);
 }
 
 static void
 cb_gnm_so_path_changed (GnmSOPath const *sop,
-			  G_GNUC_UNUSED GParamSpec *pspec,
-			  GnmSOPathView *group)
+			G_GNUC_UNUSED GParamSpec *pspec,
+			GnmSOPathView *group)
 {
 	GList *ptr = GOC_GROUP (group)->children;
 	for (; ptr && ptr->data; ptr = ptr->next)
@@ -439,8 +440,10 @@ gnm_so_path_prep_sax_parser (SheetObject *so, GsfXMLIn *xin,
 	static GsfXMLInDoc *doc = NULL;
 	GnmSOPath *sop = GNM_SO_PATH(so);
 
-	if (NULL == doc)
+	if (NULL == doc) {
 		doc = gsf_xml_in_doc_new (dtd, NULL);
+		gnm_xml_in_doc_dispose_on_exit (&doc);
+	}
 	gsf_xml_in_push_state (xin, doc, NULL, NULL, attrs);
 
 	for (; attrs != NULL && attrs[0] && attrs[1] ; attrs += 2)
@@ -644,7 +647,7 @@ gnm_so_path_finalize (GObject *object)
 static void
 gnm_so_path_class_init (GObjectClass *gobject_class)
 {
-	SheetObjectClass *so_class = SHEET_OBJECT_CLASS (gobject_class);
+	SheetObjectClass *so_class = GNM_SO_CLASS (gobject_class);
 
 	gnm_so_path_parent_class = g_type_class_peek_parent (gobject_class);
 
@@ -692,4 +695,4 @@ gnm_so_path_init (GObject *obj)
 
 GSF_CLASS (GnmSOPath, gnm_so_path,
 	   gnm_so_path_class_init, gnm_so_path_init,
-	   SHEET_OBJECT_TYPE)
+	   GNM_SO_TYPE)
