@@ -9,9 +9,9 @@
 
 G_BEGIN_DECLS
 
-#define WORKBOOK_TYPE        (workbook_get_type ())
-#define WORKBOOK(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), WORKBOOK_TYPE, Workbook))
-#define IS_WORKBOOK(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), WORKBOOK_TYPE))
+#define GNM_WORKBOOK_TYPE        (workbook_get_type ())
+#define WORKBOOK(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), GNM_WORKBOOK_TYPE, Workbook))
+#define GNM_IS_WORKBOOK(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), GNM_WORKBOOK_TYPE))
 
 GType       workbook_get_type            (void);
 Workbook   *workbook_new                 (void);
@@ -45,10 +45,12 @@ unsigned    workbook_find_command	(Workbook *wb,
 GnmExprSharer *workbook_share_expressions (Workbook *wb, gboolean freeit);
 void        workbook_optimize_style     (Workbook *wb);
 
+void        workbook_update_graphs      (Workbook *wb);
+
 /* IO Routines */
 gboolean       workbook_set_saveinfo	(Workbook *wb, GOFileFormatLevel lev,
 					 GOFileSaver *saver);
-void           workbook_update_history  (Workbook *wb, file_save_as_t type);
+void           workbook_update_history  (Workbook *wb, GnmFileSaveAsStyle type);
 GOFileSaver *workbook_get_file_saver	(Workbook *wb);
 GOFileSaver *workbook_get_file_exporter	(Workbook *wb);
 gchar const *workbook_get_last_export_uri (Workbook *wb);
